==> ejc-zdsmaterialb-api-3.0.0-20241114.025133-43-sources.jar: com/ejianc/business/zdsmaterial/plan/control/vo/ControlPlanSumDetailVO.java <==
package com.ejianc.business.zdsmaterial.plan.control.vo;

import java.math.*;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 物资总控计划汇总明细
 * 
 * @author generator
 * 
 */
public class ControlPlanSumDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long planId; // 主表主键ID
    private Long materialId; // 物资主键
    private String materialCode; // 物料编码
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String property; // 属性
    private String propertyValue; // 属性值
    private Long unitId; // 计量单位Id
    private String unitName; // 计量单位名称
    private BigDecimal num; // 总控量
    private String memo; // 备注
    private Integer sourceType; // 来源：1-档案，2-新增
    private Integer rowType; // 行类型：1-新增，2-变更
    private BigDecimal sumNum; // 原始总控量
    private BigDecimal purchaseNum; // 累计采购量
    private String sourceId; // 来源单据主键
    private String sourceDetailId; // 来源明细主键
    private Integer billType; // 单据类型：1-编制，2-变更
    private BigDecimal planNum; // 采购计划量
    private String productCode; // 产品代码
    private String materialTypeCode; // 物资分类编码
    private Long brandId; //品牌主键
    private String brandName; // 品牌名称
    public String getBrandName() {
        return brandName;
    }
    private Integer quoteType; // 引用状态 1-未引用 2-已引用
    private BigDecimal surplusPlanNum ; // 剩余计划量


    //子表导出使用字段
    private BigDecimal deliveryNum; //发货数量
    private BigDecimal acceptNum; //验收数量
    private BigDecimal inStoreNum; //入库数量
    private BigDecimal pickNum; //分包领料数量
    private BigDecimal surplusNum; //库存数量

    public BigDecimal getDeliveryNum() {
        return deliveryNum;
    }

    public void setDeliveryNum(BigDecimal deliveryNum) {
        this.deliveryNum = deliveryNum;
    }

    public BigDecimal getAcceptNum() {
        return acceptNum;
    }

    public void setAcceptNum(BigDecimal acceptNum) {
        this.acceptNum = acceptNum;
    }

    public BigDecimal getInStoreNum() {
        return inStoreNum;
    }

    public void setInStoreNum(BigDecimal inStoreNum) {
        this.inStoreNum = inStoreNum;
    }

    public BigDecimal getPickNum() {
        return pickNum;
    }

    public void setPickNum(BigDecimal pickNum) {
        this.pickNum = pickNum;
    }

    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }

    public Integer getRowType() {
        return rowType;
    }

    public void setRowType(Integer rowType) {
        this.rowType = rowType;
    }

    public BigDecimal getSurplusPlanNum() {
        return surplusPlanNum;
    }

    public void setSurplusPlanNum(BigDecimal surplusPlanNum) {
        this.surplusPlanNum = surplusPlanNum;
    }

    public Integer getQuoteType() {
        return quoteType;
    }

    public void setQuoteType(Integer quoteType) {
        this.quoteType = quoteType;
    }


    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }
    @ReferSerialTransfer(referCode="ref-zdsBrand")
    public Long getBrandId() {
        return brandId;
    }
    @ReferDeserialTransfer
    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }
    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getProperty() {
        return property;
    }

    public void setProperty(String property) {
        this.property = property;
    }
    public String getPropertyValue() {
        return propertyValue;
    }

    public void setPropertyValue(String propertyValue) {
        this.propertyValue = propertyValue;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    public BigDecimal getSumNum() {
        return sumNum;
    }

    public void setSumNum(BigDecimal sumNum) {
        this.sumNum = sumNum;
    }
    public BigDecimal getPurchaseNum() {
        return purchaseNum;
    }

    public void setPurchaseNum(BigDecimal purchaseNum) {
        this.purchaseNum = purchaseNum;
    }
    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
    public String getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(String sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public Integer getBillType() {
        return billType;
    }

    public void setBillType(Integer billType) {
        this.billType = billType;
    }
    public BigDecimal getPlanNum() {
        return planNum;
    }

    public void setPlanNum(BigDecimal planNum) {
        this.planNum = planNum;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }
    
}

==> ejc-zdsmaterialb-api-3.0.0-20251112.061841-89-sources.jar: com/ejianc/business/zdsmaterial/plan/control/vo/ControlPlanSumDetailVO.java <==
package com.ejianc.business.zdsmaterial.plan.control.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 物资总控计划汇总明细
 * 
 * @author generator
 * 
 */
public class ControlPlanSumDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long planId; // 主表主键ID
    private Long materialId; // 物资主键
    private String materialCode; // 物料编码
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String property; // 属性
    private String propertyValue; // 属性值
    private Long unitId; // 计量单位Id
    private String unitName; // 计量单位名称
    private BigDecimal num; // 总控量
    private String memo; // 备注
    private Integer sourceType; // 来源：1-档案，2-新增
    private Integer rowType; // 行类型：1-新增，2-变更
    private BigDecimal sumNum; // 原始总控量
    private BigDecimal purchaseNum; // 累计采购量
    private String sourceId; // 来源单据主键
    private String sourceDetailId; // 来源明细主键
    private Integer billType; // 单据类型：1-编制，2-变更
    private BigDecimal planNum; // 采购计划量
    private String productCode; // 产品代码
    private String materialTypeCode; // 物资分类编码
    private Long brandId; //品牌主键
    private String brandName; // 品牌名称
    public String getBrandName() {
        return brandName;
    }
    private Integer quoteType; // 引用状态 1-未引用 2-已引用
    private BigDecimal surplusPlanNum ; // 剩余计划量


    //子表导出使用字段
    private BigDecimal deliveryNum; //发货数量
    private BigDecimal acceptNum; //验收数量
    private BigDecimal inStoreNum; //入库数量
    private BigDecimal pickNum; //分包领料数量
    private BigDecimal surplusNum; //库存数量

    public BigDecimal getDeliveryNum() {
        return deliveryNum;
    }

    public void setDeliveryNum(BigDecimal deliveryNum) {
        this.deliveryNum = deliveryNum;
    }

    public BigDecimal getAcceptNum() {
        return acceptNum;
    }

    public void setAcceptNum(BigDecimal acceptNum) {
        this.acceptNum = acceptNum;
    }

    public BigDecimal getInStoreNum() {
        return inStoreNum;
    }

    public void setInStoreNum(BigDecimal inStoreNum) {
        this.inStoreNum = inStoreNum;
    }

    public BigDecimal getPickNum() {
        return pickNum;
    }

    public void setPickNum(BigDecimal pickNum) {
        this.pickNum = pickNum;
    }

    public BigDecimal getSurplusNum() {
        return surplusNum;
    }

    public void setSurplusNum(BigDecimal surplusNum) {
        this.surplusNum = surplusNum;
    }

    public Integer getRowType() {
        return rowType;
    }

    public void setRowType(Integer rowType) {
        this.rowType = rowType;
    }

    public BigDecimal getSurplusPlanNum() {
        return surplusPlanNum;
    }

    public void setSurplusPlanNum(BigDecimal surplusPlanNum) {
        this.surplusPlanNum = surplusPlanNum;
    }

    public Integer getQuoteType() {
        return quoteType;
    }

    public void setQuoteType(Integer quoteType) {
        this.quoteType = quoteType;
    }


    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }
    @ReferSerialTransfer(referCode="ref-zdsBrand")
    public Long getBrandId() {
        return brandId;
    }
    @ReferDeserialTransfer
    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }
    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getProperty() {
        return property;
    }

    public void setProperty(String property) {
        this.property = property;
    }
    public String getPropertyValue() {
        return propertyValue;
    }

    public void setPropertyValue(String propertyValue) {
        this.propertyValue = propertyValue;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }
    public BigDecimal getSumNum() {
        return sumNum;
    }

    public void setSumNum(BigDecimal sumNum) {
        this.sumNum = sumNum;
    }
    public BigDecimal getPurchaseNum() {
        return purchaseNum;
    }

    public void setPurchaseNum(BigDecimal purchaseNum) {
        this.purchaseNum = purchaseNum;
    }
    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
    public String getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(String sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    public Integer getBillType() {
        return billType;
    }

    public void setBillType(Integer billType) {
        this.billType = billType;
    }
    public BigDecimal getPlanNum() {
        return planNum;
    }

    public void setPlanNum(BigDecimal planNum) {
        this.planNum = planNum;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }
    
}
